@@ -631,13 +631,15 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
             'renamed': renamed
         }
 
+        user = changeSet.get('user', 'unknown user')
+
         commit['author'] = {
             'date': date,
-            'name': changeSet['user'],
+            'name': user,
         }
         commit['committer'] = {
             'date': date,
-            'name': changeSet['user']
+            'name': user
         }
 
         commits.append(commit)
