@@ -48,6 +48,8 @@ def get_last_branch_changeSet(branch, numberOfChangets):
 
     output_list = [item for item in output.split("-" * 79 + '\n\n') if item]
 
+    idx = 0
+
     for changeset_raw in output_list:
         changeSetDict = {}
         itemsDict = {}
@@ -66,7 +68,9 @@ def get_last_branch_changeSet(branch, numberOfChangets):
                 changeset_info_item = changeset_info_item.replace('\n\n', '\n')
                 changeset_items.append(changeset_info_item)
 
+        idx += 1
         for changeset_item in changeset_items:
+
             for item in pattern.finditer(changeset_item):
                 propertyName, propertyData = item.groups()
                 propertyName = propertyName.lstrip().rstrip().replace(' ', '_').lower()
@@ -74,6 +78,9 @@ def get_last_branch_changeSet(branch, numberOfChangets):
 
                 changeSetDict[propertyName] = propertyData
 
+                if propertyName == 'user':
+                    print(f'{idx}\t{propertyName}: {propertyData}')
+
                 if propertyName == 'items':
                     for i in propertyData.split('\n'):
                         i = i.lstrip().rstrip()
@@ -229,13 +236,14 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
             'renamed': renamed
         }
 
+        user = changeSet.get('user', 'unknown user')
         commit['author'] = {
             'date': date,
-            'name': changeSet['user'],
+            'name': user,
         }
         commit['committer'] = {
             'date': date,
-            'name': changeSet['user']
+            'name': user
         }
 
         commits.append(commit)
@@ -302,8 +310,10 @@ def wrap_changeset_push_event(arr, rest_api_data, file_tree=None, isBlameRequire
     }
 
     data = to_iso(data)
-    return json.dumps(data)
+    # return json.dumps(data)
+    return data
 
 
 data = wrap_changeset_push_event(get_last_branch_changeSet('branch', numberOfChangets=None), rest_api_data=False)
+
 print('Finish')
